@@ -53,7 +53,7 @@ def delete_or_downsize_instance_recommendation(self) -> list:
                                 'LaunchTime': instance['LaunchTime']
                             },
                             'Recommendation Reason': {
-                                'Datapoints': [float('{:.2f}'.format(x)) for x in tmp_lst_cpu]
+                                'Average CPU Datapoints(7 days)': [float('{:.2f}'.format(x)) for x in tmp_lst_cpu]
                             }
                         }
                         recommendation.append(temp)
@@ -64,6 +64,10 @@ def delete_or_downsize_instance_recommendation(self) -> list:
                         avg = avg / len(tmp_lst_cpu)
 
                         if avg < 5:
+                            try:
+                                tags = instance['Tags']
+                            except KeyError:
+                                tags = None
                             temp = {
                                 'Service Name': 'EC2 Instance',
                                 'Id': instance['InstanceId'],
@@ -72,11 +76,11 @@ def delete_or_downsize_instance_recommendation(self) -> list:
                                 'Metadata': {
                                     'Region': region,
                                     'Instance Type': instance['InstanceType'],
-                                    'Tags': instance['Tags'],
+                                    'Tags': tags,
                                     'LaunchTime': instance['LaunchTime']
                                 },
                                 'Recommendation Reason': {
-                                    'Datapoints': [float('{:.2f}'.format(x)) for x in tmp_lst_cpu]
+                                    'Average CPU Datapoints(7 days)': [float('{:.2f}'.format(x)) for x in tmp_lst_cpu]
                                 }
                             }
                             recommendation.append(temp)
